@@ -92,9 +92,9 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.back_3.clicked.connect(self.back_2)
         self.ui.back_4.clicked.connect(self.back_2)
         #self.ui.updater.clicked.connect(self.update)
-        self.ui.search.clicked.connect(self.search)
+        #self.ui.search.clicked.connect(self.search)
         self.ui.sound.toggled.connect(self.sound)
-        self.ui.start_update.clicked.connect(self.updating)
+        #self.ui.start_update.clicked.connect(self.updating)
         self.ui.vollbild.toggled.connect(self.vollbild)
         self.ui.hochformat.toggled.connect(self.format)
         self.ui.nextquest.clicked.connect(self.choose_frage)
